function b = diff(a,x)
% function B=diff(A,X)
%
% DESCRIPTION 
%   Differentiate a polynomial.
%   
% INPUTS 
%   A: polynomial 
%   X: differentiate with respect to X.
%
% OUTPUTS  
%   B: polynomial
%  
% SYNTAX 
%   B = diff(A,X);
%     Differentiate the polynomial, A, with to X.  A should be a
%     polynomial and X should be a polynomial variable or a string.  
%     Differentiation is done element-by-element if A is a matrix.
%
% EXAMPLE
%   pvar x y z;
%   f = 2*x^3+5*y*z-2*x*z^2;
%   df = diff(f,x)
%
% See also: jacobian

% 11/5/2002: PJS  Initial Coding  

% Error Checking
if nargin~=2 
    error('Error in calling diff');
end

if ispvar(x) 
    x = char(x);
    x = x{1};
elseif ~ischar(x)
    error('X must be a polynomial variable or a string');
end

% Get polynomial info about a
adeg = a.degmat;
avar = a.varname;
sza = a.matdim;
nra = sza(1);
nca = sza(2);
acoef = a.coefficient;

% Find variable we are differentiating with respect to.
varnumb = find( strcmp(avar,x) );

% Differentiate
if isempty(varnumb)
    b = polynomial(0);
else
    acoef = acoef.*repmat(adeg(:,varnumb),[1 nra*nca]);
    adeg(:,varnumb) = max( adeg(:,varnumb)-1 , 0);    
    chkval = 0; % skip validity check
    b = polynomial(acoef,adeg,avar,[nra nca],chkval);
    b = combine(b);
end



