function c = eq(a,b)
%  ==  Equal.
%     A == B does element by element comparisons between A and B
%     and returns a matrix of the same size with elements set to logical 1
%     where the relation is true and elements set to logical 0 where it is
%     not.  A and B must have the same dimensions unless one is a
%     scalar. A scalar can be compared with any size array.
%  
%     C = EQ(A,B) is called for the syntax 'A == B' when A or B is an
%     object.
    
% 6/14/2002: PJS  Initial Coding  

a = polynomial(a);
sza = size(a);

b = polynomial(b);
szb = size(b);


if isempty(a) || isempty(b)
        
    if isempty(a) && all(szb==[1 1])
        % empty==scalar returns empty(sza)
        c=logical(zeros(sza));
        return;
    elseif isempty(b) && all(sza==[1 1])
        % scalar==empty returns empty(szb)
        c=logical(zeros(szb));
        return;
    elseif all(sza==szb)
        % empty==empty returns empty
        c=logical(zeros(sza));
        return;
    else
        error('Matrix dimensions must agree.');
    end   
elseif all(sza==szb)
    % Matrix == Matrix case
    d = a-b;
    [nrd,ncd] =size(d);
    dcoef = d.coefficient; 
    dcoef = sum(abs(dcoef),1);
    c = full(dcoef)==0;
    c = reshape(c,nrd,ncd);  
    
elseif all(sza==[1 1]) | all(szb==[1 1])
    % Scalar == Matrix:   
  
    % Make first term be the scalar.  
    if ~all(sza==[1 1])
        temp = a;
        a = b;
        b = temp;
        szb = sza;
    end

    % Turn into matrix==matrix
    a.coefficient = repmat(a.coefficient,[1 szb(1)*szb(2)]);
    a.matdim = szb;    
    c = eq(a,b);

else  
  error('Matrix dimensions must agree');
end



