function [b,I,J]=unique(a)
%UNIQUE Set unique.
%   B = UNIQUE(A) for the array A returns the same values as in A but
%   with no repetitions. B will also be sorted. 
%
%   [B,I,J] = UNIQUE(...) also returns index vectors I and J such
%   that B = A(I) and A = B(J) (or B = A(I,:) and A = B(J,:)).
%   

% 4/27/2006: PJS  Initial Coding  -- Based matlab\ops\unique.m


% Error Checking
if nargin~=1
    error('[b,I,J]=unique(a)');
end

sza = size(a);
numa = sza(1)*sza(2);

if isempty(a) % empty input    
    % XXX Might need to modify code for 1x0 or 0x1
    b = polynomial;
    I=[];
    J=[];
    return
elseif all(sza==[1 1]) % scalar input
    b = a;
    I=1;
    J=1;
    return
else
    % Convert to a column vector and sort
    L.type = '()';
    L.subs = {':'};
    a = subsref(a,L);    
    [b,I] = sort(a);

    % Find locations of unique entries and create list
    L.subs = {2:numa,1};
    db = subsref(b,L);
    L.subs = {1:numa-1,1};    
    db = db - subsref(b,L);

    d = logical([(db~=0); 1]);
    L.subs = {find(d),1};    
    b = subsref(b,L);

    % Create indices
    J = cumsum([1;d]);    % Lists position, starting at 1.
    J(end) = [];          % Remove extra element introduced by d.
    J(I) = J;             % Re-reference POS to indexing of SORT.
    I = I(d);

    if sza(1)==1
        b = b.';
        J = J.';
        I = I.';
    end
end
  